library(ggplot2)
library(dplyr)

graph_time = 10800

BSW <- read.csv("./Data/helsinki_random_black_holes_BSW.csv")
BSW_df <- data.frame(x = BSW$black_holes, y = BSW$latency_avg, time = BSW$sim_time)
BSW_df <- filter(BSW_df, time == graph_time)
BSW_df['Protocol']='Binary Spray and Wait'

MP <- read.csv("./Data/helsinki_random_black_holes_MP.csv")
MP_df <- data.frame(x = MP$black_holes, y = MP$latency_avg, time = MP$sim_time)
MP_df <- filter(MP_df, time == graph_time)
MP_df['Protocol']='MaxProp'

PH <- read.csv("./Data/helsinki_random_black_holes_PH.csv")
PH_df <- data.frame(x = PH$black_holes, y = PH$latency_avg, time = PH$sim_time)
PH_df <- filter(PH_df, time == graph_time)
PH_df['Protocol']='PRoPHET'

EP <- read.csv("./Data/helsinki_random_black_holes_EP.csv")
EP_df <- data.frame(x = EP$black_holes, y = EP$latency_avg, time = EP$sim_time)
EP_df <- filter(EP_df, time == graph_time)
EP_df['Protocol']='Epidemic'

data <- rbind(rbind(BSW_df, MP_df, PH_df, EP_df))

paste('./Latency/', graph_time, '_Latency.png', sep = "")
png(filename= paste('./Latency/', graph_time, '_Latency.png', sep = ""))
ggplot(data, aes(x = x, y = y)) +
  geom_point(aes(colour = Protocol)) + # Points and color by group
  geom_smooth(se = FALSE, aes(colour = Protocol)) +
  ggtitle(paste("Latency at ", graph_time, " Seconds", sep = "")) +
  scale_color_discrete("Protocol") +  # Change legend title
  xlab("% Black Holes") +              # X-axis label
  ylab("Latency (s)")  +             # Y-axis label
  theme(axis.line = element_line(colour = "black", size = 0.24))

dev.off()