library(ggplot2)

BSW <- read.csv("./Data/helsinki_random_grey_holes_BSW.csv")
BSW_df <- data.frame(x = BSW$black_holes, y = BSW$latency_avg)
BSW_df <- aggregate(BSW_df[, 2:2], list(BSW_df$x), mean)
BSW_df['Protocol']='Binary Spray and Wait'

MP <- read.csv("./Data/helsinki_random_grey_holes_MP.csv")
MP_df <- data.frame(x = MP$black_holes, y = MP$latency_avg)
MP_df <- aggregate(MP_df[, 2:2], list(MP_df$x), mean)
MP_df['Protocol']='MaxProp'

PH <- read.csv("./Data/helsinki_random_grey_holes_PH.csv")
PH_df <- data.frame(x = PH$black_holes, y = PH$latency_avg)
PH_df <- aggregate(PH_df[, 2:2], list(PH_df$x), mean)
PH_df['Protocol']='PRoPHET'

EP <- read.csv("./Data/helsinki_random_grey_holes_EP.csv")
EP_df <- data.frame(x = EP$black_holes, y = EP$latency_avg)
EP_df <- aggregate(EP_df[, 2:2], list(EP_df$x), mean)
EP_df['Protocol']='Epidemic'

data <- rbind(rbind(BSW_df, MP_df, PH_df, EP_df))
data

png(filename='average_latency_avg_GH.png')
ggplot(data, aes(x = Group.1, y = x)) +
  geom_point(aes(colour = Protocol)) + # Points and color by group
  geom_smooth(se = FALSE, aes(colour = Protocol)) +
  ggtitle("Average Latency") +
  scale_color_discrete("Protocol") +  # Change legend title
  xlab("% Grey Holes") +              # X-axis label
  ylab("Latency (s)")  +             # Y-axis label
  theme(axis.line = element_line(colour = "black", size = 0.24))

dev.off()