library('plotly')
library('htmlwidgets')
library('RCurl')

image_file <- "./Data/helsinki_underlay.png"
txt <- RCurl::base64Encode(readBin(image_file, "raw", file.info(image_file)[1, "size"]), "txt")

data <- read.csv("./Data/multi_snap.csv")

p <- data %>%
  plot_ly(
    x = ~x, 
    y = ~-y, 
    color = ~node_type, 
    colors = c("red", "black"), 
    frame = ~snapshot_time, 
    type = 'scatter',
    mode = 'markers'
  ) %>%
  layout(
    images = list(
      list(
        source =  paste('data:image/png;base64', txt, sep=','),
        xref = "x",
        yref = "y",
        x = 300,
        y = -70,
        sizex = 4250,
        sizey = 3000,
        sizing = "stretch",
        opacity = 0.4,
        layer = "below"
      )
    )
  )
htmlwidgets::saveWidget(p, "animated.html")